Documentation
¶
Overview ¶
The ghstatus package allows you to check the system status of GitHub from your own applications. The status information is retrieved from GitHub's system status API (https://status.github.com/api).
Index ¶
Constants ¶
const ( Good = "good" Minor = "minor" Major = "major" )
Possible status values set in Status and Message.
const ServiceURL = "https://status.github.com"
The URL of GitHub's system status API.
Variables ¶
var DefaultClient = &Client{ HTTPClient: http.DefaultClient, ServiceURL: ServiceURL, }
The default client to talk to GitHub's system status API.
Functions ¶
This section is empty.
Types ¶
type Client ¶
A client to talk to GitHub's system status API.
func (*Client) GetLastMessage ¶
Get last human communication, status, and timestamp.
func (*Client) GetMessages ¶
Get most recent human communications with status and timestamp.
Click to show internal directories.
Click to hide internal directories.